@@ -12,53 +12,53 @@
 
 #pragma once
 
-#if defined(__linux) || defined(linux) || defined(__linux__)
+#if defined(__linux) || defined(linux) || defined(__linux__) || defined(__FreeBSD__)
 
-#include <pika/config.hpp>
-#include <pika/assert.hpp>
-#include <pika/coroutines/detail/get_stack_pointer.hpp>
-#include <pika/coroutines/detail/posix_utility.hpp>
-#include <pika/coroutines/detail/swap_context.hpp>
-#include <pika/util/get_and_reset_value.hpp>
+# include <pika/config.hpp>
+# include <pika/assert.hpp>
+# include <pika/coroutines/detail/get_stack_pointer.hpp>
+# include <pika/coroutines/detail/posix_utility.hpp>
+# include <pika/coroutines/detail/swap_context.hpp>
+# include <pika/util/get_and_reset_value.hpp>
 
-#include <fmt/format.h>
+# include <fmt/format.h>
 
-#include <atomic>
-#include <cstddef>
-#include <cstdint>
-#include <cstdlib>
-#include <stdexcept>
-#include <sys/param.h>
+# include <atomic>
+# include <cstddef>
+# include <cstdint>
+# include <cstdlib>
+# include <stdexcept>
+# include <sys/param.h>
 
-#if defined(PIKA_HAVE_STACKOVERFLOW_DETECTION)
+# if defined(PIKA_HAVE_STACKOVERFLOW_DETECTION)
 
-#include <cstring>
-#include <signal.h>
-#include <stdlib.h>
-#include <strings.h>
+#  include <cstring>
+#  include <signal.h>
+#  include <stdlib.h>
+#  include <strings.h>
 
-#if !defined(SEGV_STACK_SIZE)
-#define SEGV_STACK_SIZE MINSIGSTKSZ + 4096
-#endif
+#  if !defined(SEGV_STACK_SIZE)
+#   define SEGV_STACK_SIZE MINSIGSTKSZ + 4096
+#  endif
 
-#endif
+# endif
 
-#include <iomanip>
-#include <iostream>
+# include <iomanip>
+# include <iostream>
 
-#if defined(PIKA_HAVE_VALGRIND)
-#if defined(__GNUG__) && !defined(__INTEL_COMPILER)
-#if defined(PIKA_GCC_DIAGNOSTIC_PRAGMA_CONTEXTS)
-#pragma GCC diagnostic push
-#endif
-#pragma GCC diagnostic ignored "-Wpointer-arith"
-#endif
-#include <valgrind/valgrind.h>
-#endif
+# if defined(PIKA_HAVE_VALGRIND)
+#  if defined(__GNUG__) && !defined(__INTEL_COMPILER)
+#   if defined(PIKA_GCC_DIAGNOSTIC_PRAGMA_CONTEXTS)
+#    pragma GCC diagnostic push
+#   endif
+#   pragma GCC diagnostic ignored "-Wpointer-arith"
+#  endif
+#  include <valgrind/valgrind.h>
+# endif
 
-#if defined(PIKA_HAVE_ADDRESS_SANITIZER)
-#include <sanitizer/asan_interface.h>
-#endif
+# if defined(PIKA_HAVE_ADDRESS_SANITIZER)
+#  include <sanitizer/asan_interface.h>
+# endif
 
 /*
  * Defining PIKA_COROUTINE_NO_SEPARATE_CALL_SITES will disable separate
@@ -68,15 +68,13 @@
  * default.
  */
 
-#if defined(__x86_64__)
+# if defined(__x86_64__)
 extern "C" void swapcontext_stack(void***, void**) noexcept;
 extern "C" void swapcontext_stack2(void***, void**) noexcept;
-#else
-extern "C" void swapcontext_stack(void***, void**) noexcept
-    __attribute((regparm(2)));
-extern "C" void swapcontext_stack2(void***, void**) noexcept
-    __attribute((regparm(2)));
-#endif
+# else
+extern "C" void swapcontext_stack(void***, void**) noexcept __attribute((regparm(2)));
+extern "C" void swapcontext_stack2(void***, void**) noexcept __attribute((regparm(2)));
+# endif
 
 ///////////////////////////////////////////////////////////////////////////////
 namespace pika::threads::coroutines {
@@ -104,42 +102,34 @@ namespace pika::threads::coroutines {
         public:
             x86_linux_context_impl_base()
               : m_sp(nullptr)
-#if defined(PIKA_HAVE_ADDRESS_SANITIZER)
+# if defined(PIKA_HAVE_ADDRESS_SANITIZER)
               , asan_fake_stack(nullptr)
               , asan_stack_bottom(nullptr)
               , asan_stack_size(0)
-#endif
+# endif
             {
             }
 
             void prefetch() const
             {
-#if defined(__x86_64__)
+# if defined(__x86_64__)
                 PIKA_ASSERT(sizeof(void*) == 8);
-#else
+# else
                 PIKA_ASSERT(sizeof(void*) == 4);
-#endif
+# endif
 
                 __builtin_prefetch(m_sp, 1, 3);
                 __builtin_prefetch(m_sp, 0, 3);
-                __builtin_prefetch(
-                    static_cast<void**>(m_sp) + 64 / sizeof(void*), 1, 3);
-                __builtin_prefetch(
-                    static_cast<void**>(m_sp) + 64 / sizeof(void*), 0, 3);
-#if !defined(__x86_64__)
-                __builtin_prefetch(
-                    static_cast<void**>(m_sp) + 32 / sizeof(void*), 1, 3);
-                __builtin_prefetch(
-                    static_cast<void**>(m_sp) + 32 / sizeof(void*), 0, 3);
-                __builtin_prefetch(
-                    static_cast<void**>(m_sp) - 32 / sizeof(void*), 1, 3);
-                __builtin_prefetch(
-                    static_cast<void**>(m_sp) - 32 / sizeof(void*), 0, 3);
-#endif
-                __builtin_prefetch(
-                    static_cast<void**>(m_sp) - 64 / sizeof(void*), 1, 3);
-                __builtin_prefetch(
-                    static_cast<void**>(m_sp) - 64 / sizeof(void*), 0, 3);
+                __builtin_prefetch(static_cast<void**>(m_sp) + 64 / sizeof(void*), 1, 3);
+                __builtin_prefetch(static_cast<void**>(m_sp) + 64 / sizeof(void*), 0, 3);
+# if !defined(__x86_64__)
+                __builtin_prefetch(static_cast<void**>(m_sp) + 32 / sizeof(void*), 1, 3);
+                __builtin_prefetch(static_cast<void**>(m_sp) + 32 / sizeof(void*), 0, 3);
+                __builtin_prefetch(static_cast<void**>(m_sp) - 32 / sizeof(void*), 1, 3);
+                __builtin_prefetch(static_cast<void**>(m_sp) - 32 / sizeof(void*), 0, 3);
+# endif
+                __builtin_prefetch(static_cast<void**>(m_sp) - 64 / sizeof(void*), 1, 3);
+                __builtin_prefetch(static_cast<void**>(m_sp) - 64 / sizeof(void*), 0, 3);
             }
 
             /**
@@ -153,40 +143,36 @@ namespace pika::threads::coroutines {
             friend void swap_context(x86_linux_context_impl_base& from,
                 x86_linux_context_impl_base const& to, yield_hint);
 
-#if defined(PIKA_HAVE_ADDRESS_SANITIZER)
+# if defined(PIKA_HAVE_ADDRESS_SANITIZER)
             void start_switch_fiber(void** fake_stack)
             {
-                __sanitizer_start_switch_fiber(
-                    fake_stack, asan_stack_bottom, asan_stack_size);
+                __sanitizer_start_switch_fiber(fake_stack, asan_stack_bottom, asan_stack_size);
             }
-            void start_yield_fiber(
-                void** fake_stack, x86_linux_context_impl_base& caller)
+            void start_yield_fiber(void** fake_stack, x86_linux_context_impl_base& caller)
             {
-                __sanitizer_start_switch_fiber(fake_stack,
-                    caller.asan_stack_bottom, caller.asan_stack_size);
+                __sanitizer_start_switch_fiber(
+                    fake_stack, caller.asan_stack_bottom, caller.asan_stack_size);
             }
             void finish_yield_fiber(void* fake_stack)
             {
-                __sanitizer_finish_switch_fiber(
-                    fake_stack, &asan_stack_bottom, &asan_stack_size);
+                __sanitizer_finish_switch_fiber(fake_stack, &asan_stack_bottom, &asan_stack_size);
             }
-            void finish_switch_fiber(
-                void* fake_stack, x86_linux_context_impl_base& caller)
+            void finish_switch_fiber(void* fake_stack, x86_linux_context_impl_base& caller)
             {
-                __sanitizer_finish_switch_fiber(fake_stack,
-                    &caller.asan_stack_bottom, &caller.asan_stack_size);
+                __sanitizer_finish_switch_fiber(
+                    fake_stack, &caller.asan_stack_bottom, &caller.asan_stack_size);
             }
-#endif
+# endif
 
         protected:
             void** m_sp;
 
-#if defined(PIKA_HAVE_ADDRESS_SANITIZER)
+# if defined(PIKA_HAVE_ADDRESS_SANITIZER)
         public:
             void* asan_fake_stack;
             void const* asan_stack_bottom;
             std::size_t asan_stack_size;
-#endif
+# endif
         };
 
         template <typename CoroutineImpl>
@@ -205,9 +191,8 @@ namespace pika::threads::coroutines {
              *  a new stack. The stack size can be optionally specified.
              */
             explicit x86_linux_context_impl(std::ptrdiff_t stack_size = -1)
-              : m_stack_size(stack_size == -1 ?
-                        static_cast<std::ptrdiff_t>(default_stack_size) :
-                        stack_size)
+              : m_stack_size(
+                    stack_size == -1 ? static_cast<std::ptrdiff_t>(default_stack_size) : stack_size)
               , m_stack(nullptr)
             {
             }
@@ -220,50 +205,45 @@ namespace pika::threads::coroutines {
                 if (0 != (m_stack_size % EXEC_PAGESIZE))
                 {
                     throw std::runtime_error(
-                        fmt::format("stack size of {} is not page "
-                                    "aligned, page size is {}",
+                        fmt::format("stack size of {} is not page aligned, page size is {}",
                             m_stack_size, EXEC_PAGESIZE));
                 }
 
                 if (0 >= m_stack_size)
                 {
-                    throw std::runtime_error(fmt::format(
-                        "stack size of {} is invalid", m_stack_size));
+                    throw std::runtime_error(
+                        fmt::format("stack size of {} is invalid", m_stack_size));
                 }
 
-                m_stack =
-                    posix::alloc_stack(static_cast<std::size_t>(m_stack_size));
+                m_stack = posix::alloc_stack(static_cast<std::size_t>(m_stack_size));
                 if (m_stack == nullptr)
                 {
-                    throw std::runtime_error(
-                        "could not allocate memory for stack");
+                    throw std::runtime_error("could not allocate memory for stack");
                 }
 
-                posix::watermark_stack(
-                    m_stack, static_cast<std::size_t>(m_stack_size));
+                posix::watermark_stack(m_stack, static_cast<std::size_t>(m_stack_size));
 
                 using fun = void(void*);
                 fun* funp = trampoline<CoroutineImpl>;
 
                 m_sp = (static_cast<void**>(m_stack) +
-                           static_cast<std::size_t>(m_stack_size) /
-                               sizeof(void*)) -
+                           static_cast<std::size_t>(m_stack_size) / sizeof(void*)) -
                     context_size;
 
                 m_sp[cb_idx] = this;
                 m_sp[funp_idx] = reinterpret_cast<void*>(funp);
 
-#if defined(PIKA_HAVE_VALGRIND) && !defined(NVALGRIND)
+# if defined(PIKA_HAVE_VALGRIND) && !defined(NVALGRIND)
                 {
                     void* eos = static_cast<char*>(m_stack) + m_stack_size;
-                    m_sp[valgrind_id_idx] = reinterpret_cast<void*>(
-                        VALGRIND_STACK_REGISTER(m_stack, eos));
+                    m_sp[valgrind_id_idx] =
+                        reinterpret_cast<void*>(VALGRIND_STACK_REGISTER(m_stack, eos));
                 }
-#endif
-#if defined(PIKA_HAVE_ADDRESS_SANITIZER)
+# endif
+# if defined(PIKA_HAVE_ADDRESS_SANITIZER)
                 asan_stack_size = m_stack_size;
                 asan_stack_bottom = const_cast<const void*>(m_stack);
-#endif
+# endif
 
                 set_sigsegv_handler();
             }
@@ -272,23 +252,19 @@ namespace pika::threads::coroutines {
             {
                 if (m_stack)
                 {
-#if defined(PIKA_HAVE_VALGRIND) && !defined(NVALGRIND)
-                    VALGRIND_STACK_DEREGISTER(
-                        reinterpret_cast<std::size_t>(m_sp[valgrind_id_idx]));
-#endif
-                    posix::free_stack(
-                        m_stack, static_cast<std::size_t>(m_stack_size));
+# if defined(PIKA_HAVE_VALGRIND) && !defined(NVALGRIND)
+                    VALGRIND_STACK_DEREGISTER(reinterpret_cast<std::size_t>(m_sp[valgrind_id_idx]));
+# endif
+                    posix::free_stack(m_stack, static_cast<std::size_t>(m_stack_size));
                 }
             }
 
-#if defined(PIKA_HAVE_STACKOVERFLOW_DETECTION) &&                              \
-    !defined(PIKA_HAVE_ADDRESS_SANITIZER)
+# if defined(PIKA_HAVE_STACKOVERFLOW_DETECTION) && !defined(PIKA_HAVE_ADDRESS_SANITIZER)
 
 // heuristic value 1 kilobyte
-#define COROUTINE_STACKOVERFLOW_ADDR_EPSILON 1000UL
+#  define COROUTINE_STACKOVERFLOW_ADDR_EPSILON 1000UL
 
-            static void check_coroutine_stack_overflow(
-                siginfo_t* infoptr, void* ctxptr)
+            static void check_coroutine_stack_overflow(siginfo_t* infoptr, void* ctxptr)
             {
                 ucontext_t* uc_ctx = static_cast<ucontext_t*>(ctxptr);
                 char* sigsegv_ptr = static_cast<char*>(infoptr->si_addr);
@@ -297,48 +273,38 @@ namespace pika::threads::coroutines {
                 //
                 char* stk_ptr = static_cast<char*>(uc_ctx->uc_stack.ss_sp);
 
-                std::ptrdiff_t addr_delta = (sigsegv_ptr > stk_ptr) ?
-                    (sigsegv_ptr - stk_ptr) :
-                    (stk_ptr - sigsegv_ptr);
+                std::ptrdiff_t addr_delta =
+                    (sigsegv_ptr > stk_ptr) ? (sigsegv_ptr - stk_ptr) : (stk_ptr - sigsegv_ptr);
 
                 // check the stack addresses, if they're < 10 apart, terminate
                 // program should filter segmentation faults caused by
                 // coroutine stack overflows from 'genuine' stack overflows
                 //
-                if (static_cast<size_t>(addr_delta) <
-                    COROUTINE_STACKOVERFLOW_ADDR_EPSILON)
+                if (static_cast<size_t>(addr_delta) < COROUTINE_STACKOVERFLOW_ADDR_EPSILON)
                 {
-                    std::cerr << "Stack overflow in coroutine at address "
-                              << std::internal << std::hex
-                              << std::setw(sizeof(sigsegv_ptr) * 2 + 2)
+                    std::cerr << "Stack overflow in coroutine at address " << std::internal
+                              << std::hex << std::setw(sizeof(sigsegv_ptr) * 2 + 2)
                               << std::setfill('0') << sigsegv_ptr << ".\n\n";
 
-                    std::cerr << "Configure the pika runtime to "
-                                 "allocate a larger "
-                                 "coroutine stack size.\n Use the "
-                                 "pika.stacks.small_size, "
-                                 "pika.stacks.medium_size,\n "
-                                 "pika.stacks.large_size, or "
-                                 "pika.stacks.huge_size "
-                                 "configuration\nflags to "
-                                 "configure coroutine stack "
-                                 "sizes.\n"
-                              << std::endl;
+                    std::cerr
+                        << "Configure the pika runtime to allocate a larger coroutine stack "
+                           "size.\n Use the pika.stacks.small_size, pika.stacks.medium_size,\n "
+                           "pika.stacks.large_size, or pika.stacks.huge_size configuration\nflags "
+                           "to configure coroutine stack sizes.\n"
+                        << std::endl;
                 }
             }
 
-            static void sigsegv_handler(
-                int signum, siginfo_t* infoptr, void* ctxptr)
+            static void sigsegv_handler(int signum, siginfo_t* infoptr, void* ctxptr)
             {
                 char* reason = strsignal(signum);
-                std::cerr << "{what}: " << (reason ? reason : "Unknown signal")
-                          << std::endl;
+                std::cerr << "{what}: " << (reason ? reason : "Unknown signal") << std::endl;
 
                 check_coroutine_stack_overflow(infoptr, ctxptr);
 
                 std::abort();
             }
-#endif
+# endif
 
             // Return the size of the reserved stack address space.
             std::ptrdiff_t get_stacksize() const
@@ -349,47 +315,44 @@ namespace pika::threads::coroutines {
             void reset_stack()
             {
                 PIKA_ASSERT(m_stack);
-                if (posix::reset_stack(
-                        m_stack, static_cast<std::size_t>(m_stack_size)))
+                if (posix::reset_stack(m_stack, static_cast<std::size_t>(m_stack_size)))
                 {
-#if defined(PIKA_HAVE_COROUTINE_COUNTERS)
+# if defined(PIKA_HAVE_COROUTINE_COUNTERS)
                     increment_stack_unbind_count();
-#endif
+# endif
                 }
             }
 
             void rebind_stack()
             {
                 PIKA_ASSERT(m_stack);
-#if defined(PIKA_HAVE_COROUTINE_COUNTERS)
+# if defined(PIKA_HAVE_COROUTINE_COUNTERS)
                 increment_stack_recycle_count();
-#endif
+# endif
 
                 // On rebind, we initialize our stack to ensure a virgin stack
                 m_sp = (static_cast<void**>(m_stack) +
-                           static_cast<std::size_t>(m_stack_size) /
-                               sizeof(void*)) -
+                           static_cast<std::size_t>(m_stack_size) / sizeof(void*)) -
                     context_size;
 
                 using fun = void(void*);
                 fun* funp = trampoline<CoroutineImpl>;
                 m_sp[cb_idx] = this;
                 m_sp[funp_idx] = reinterpret_cast<void*>(funp);
-#if defined(PIKA_HAVE_ADDRESS_SANITIZER)
+# if defined(PIKA_HAVE_ADDRESS_SANITIZER)
                 asan_stack_size = m_stack_size;
                 asan_stack_bottom = const_cast<const void*>(m_stack);
-#endif
+# endif
             }
 
             std::ptrdiff_t get_available_stack_space()
             {
-                return get_stack_ptr() -
-                    reinterpret_cast<std::size_t>(m_stack) - context_size;
+                return get_stack_ptr() - reinterpret_cast<std::size_t>(m_stack) - context_size;
             }
 
             using counter_type = std::atomic<std::int64_t>;
 
-#if defined(PIKA_HAVE_COROUTINE_COUNTERS)
+# if defined(PIKA_HAVE_COROUTINE_COUNTERS)
         private:
             static counter_type& get_stack_unbind_counter()
             {
@@ -416,16 +379,14 @@ namespace pika::threads::coroutines {
         public:
             static std::uint64_t get_stack_unbind_count(bool reset)
             {
-                return ::pika::detail::get_and_reset_value(
-                    get_stack_unbind_counter(), reset);
+                return ::pika::detail::get_and_reset_value(get_stack_unbind_counter(), reset);
             }
 
             static std::uint64_t get_stack_recycle_count(bool reset)
             {
-                return ::pika::detail::get_and_reset_value(
-                    get_stack_recycle_counter(), reset);
+                return ::pika::detail::get_and_reset_value(get_stack_recycle_counter(), reset);
             }
-#endif
+# endif
 
             friend void swap_context(x86_linux_context_impl_base& from,
                 x86_linux_context_impl_base const& to, default_hint);
@@ -436,8 +397,7 @@ namespace pika::threads::coroutines {
         private:
             void set_sigsegv_handler()
             {
-#if defined(PIKA_HAVE_STACKOVERFLOW_DETECTION) &&                              \
-    !defined(PIKA_HAVE_ADDRESS_SANITIZER)
+# if defined(PIKA_HAVE_STACKOVERFLOW_DETECTION) && !defined(PIKA_HAVE_ADDRESS_SANITIZER)
                 // concept inspired by the following links:
                 //
                 // https://rethinkdb.com/blog/handling-stack-overflow-on-custom-stacks/
@@ -455,10 +415,10 @@ namespace pika::threads::coroutines {
                 sigemptyset(&action.sa_mask);
                 sigaddset(&action.sa_mask, SIGSEGV);
                 sigaction(SIGSEGV, &action, nullptr);
-#endif
+# endif
             }
 
-#if defined(__x86_64__)
+# if defined(__x86_64__)
             /** structure of context_data:
              * 11: additional alignment (or valgrind_id if enabled)
              * 10: parm 0 of trampoline
@@ -473,14 +433,14 @@ namespace pika::threads::coroutines {
              * 1:  r14
              * 0:  r15
              **/
-#if defined(PIKA_HAVE_VALGRIND) && !defined(NVALGRIND)
+#  if defined(PIKA_HAVE_VALGRIND) && !defined(NVALGRIND)
             static const std::size_t valgrind_id_idx = 11;
-#endif
+#  endif
 
             static const std::size_t context_size = 12;
             static const std::size_t cb_idx = 10;
             static const std::size_t funp_idx = 8;
-#else
+# else
             /** structure of context_data:
              * 7: valgrind_id (if enabled)
              * 6: parm 0 of trampoline
@@ -491,25 +451,24 @@ namespace pika::threads::coroutines {
              * 1: esi
              * 0: edi
              **/
-#if defined(PIKA_HAVE_VALGRIND) && !defined(NVALGRIND)
+#  if defined(PIKA_HAVE_VALGRIND) && !defined(NVALGRIND)
             static const std::size_t context_size = 8;
             static const std::size_t valgrind_id_idx = 7;
-#else
+#  else
             static const std::size_t context_size = 7;
-#endif
+#  endif
 
             static const std::size_t cb_idx = 6;
             static const std::size_t funp_idx = 4;
-#endif
+# endif
 
             std::ptrdiff_t m_stack_size;
             void* m_stack;
 
-#if defined(PIKA_HAVE_STACKOVERFLOW_DETECTION) &&                              \
-    !defined(PIKA_HAVE_ADDRESS_SANITIZER)
+# if defined(PIKA_HAVE_STACKOVERFLOW_DETECTION) && !defined(PIKA_HAVE_ADDRESS_SANITIZER)
             struct sigaction action;
             stack_t segv_stack;
-#endif
+# endif
         };
 
         /**
@@ -517,38 +476,38 @@ namespace pika::threads::coroutines {
          * and restores the context in @p to.
          * @note This function is found by ADL.
          */
-        inline void swap_context(x86_linux_context_impl_base& from,
-            x86_linux_context_impl_base const& to, default_hint)
+        inline void swap_context(
+            x86_linux_context_impl_base& from, x86_linux_context_impl_base const& to, default_hint)
         {
             //        PIKA_ASSERT(*(void**)to.m_stack == (void*)~0);
             to.prefetch();
             swapcontext_stack(&from.m_sp, to.m_sp);
         }
 
-        inline void swap_context(x86_linux_context_impl_base& from,
-            x86_linux_context_impl_base const& to, yield_hint)
+        inline void swap_context(
+            x86_linux_context_impl_base& from, x86_linux_context_impl_base const& to, yield_hint)
         {
             //        PIKA_ASSERT(*(void**)from.m_stack == (void*)~0);
             to.prefetch();
-#if !defined(PIKA_COROUTINE_NO_SEPARATE_CALL_SITES)
+# if !defined(PIKA_COROUTINE_NO_SEPARATE_CALL_SITES)
             swapcontext_stack2(&from.m_sp, to.m_sp);
-#else
+# else
             swapcontext_stack(&from.m_sp, to.m_sp);
-#endif
+# endif
         }
     }    // namespace detail::lx
 }    // namespace pika::threads::coroutines
 
-#if defined(PIKA_HAVE_VALGRIND)
-#if defined(__GNUG__) && !defined(__INTEL_COMPILER)
-#if defined(PIKA_GCC_DIAGNOSTIC_PRAGMA_CONTEXTS)
-#pragma GCC diagnostic pop
-#endif
-#endif
-#endif
+# if defined(PIKA_HAVE_VALGRIND)
+#  if defined(__GNUG__) && !defined(__INTEL_COMPILER)
+#   if defined(PIKA_GCC_DIAGNOSTIC_PRAGMA_CONTEXTS)
+#    pragma GCC diagnostic pop
+#   endif
+#  endif
+# endif
 
 #else
 
-#error This header can only be included when compiling for linux systems.
+# error This header can only be included when compiling for linux systems.
 
 #endif
