@@ -8,8 +8,8 @@
 
 #include <pika/config.hpp>
 
-#if defined(PIKA_HAVE_P2300_REFERENCE_IMPLEMENTATION)
-#include <pika/execution_base/p2300_forward.hpp>
+#if defined(PIKA_HAVE_STDEXEC)
+# include <pika/execution_base/stdexec_forward.hpp>
 #endif
 
 #include <pika/concepts/concepts.hpp>
@@ -51,33 +51,26 @@ namespace pika::sync_wait_detail {
     };
 
     template <typename Sender>
-    using sync_wait_receiver =
-        typename sync_wait_receiver_impl<Sender>::sync_wait_receiver_type;
+    using sync_wait_receiver = typename sync_wait_receiver_impl<Sender>::sync_wait_receiver_type;
 
     template <typename Sender>
     struct sync_wait_receiver_impl<Sender>::sync_wait_receiver_type
     {
-#if defined(PIKA_HAVE_P2300_REFERENCE_IMPLEMENTATION)
+#if defined(PIKA_HAVE_STDEXEC)
         // value and error_types of the predecessor sender
-        template <template <typename...> class Tuple,
-            template <typename...> class Variant>
-        using predecessor_value_types =
-            pika::execution::experimental::value_types_of_t<Sender,
-                pika::execution::experimental::detail::empty_env, Tuple,
-                Variant>;
+        template <template <typename...> class Tuple, template <typename...> class Variant>
+        using predecessor_value_types = pika::execution::experimental::value_types_of_t<Sender,
+            pika::execution::experimental::empty_env, Tuple, Variant>;
 
         template <template <typename...> class Variant>
-        using predecessor_error_types =
-            pika::execution::experimental::error_types_of_t<Sender,
-                pika::execution::experimental::detail::empty_env, Variant>;
+        using predecessor_error_types = pika::execution::experimental::error_types_of_t<Sender,
+            pika::execution::experimental::empty_env, Variant>;
 
         // The type of the single void or non-void result that we store. If
         // there are multiple variants or multiple values sync_wait will
         // fail to compile.
-        using result_type =
-            std::decay_t<pika::execution::experimental::detail::single_result_t<
-                predecessor_value_types<pika::util::detail::pack,
-                    pika::util::detail::pack>>>;
+        using result_type = std::decay_t<pika::execution::experimental::detail::single_result_t<
+            predecessor_value_types<pika::util::detail::pack, pika::util::detail::pack>>>;
 
         // Constant to indicate if the type of the result from the
         // predecessor sender is void or not
@@ -90,36 +83,29 @@ namespace pika::sync_wait_detail {
 
         // The type of the value to store in the variant, void_value_type if
         // result_type is void, or result_type if it is not
-        using value_type =
-            std::conditional_t<is_void_result, void_value_type, result_type>;
+        using value_type = std::conditional_t<is_void_result, void_value_type, result_type>;
 
         // The type of errors to store in the variant. This in itself is a
         // variant.
-        using error_type =
-            pika::util::detail::unique_t<pika::util::detail::prepend_t<
-                pika::util::detail::transform_t<
-                    predecessor_error_types<pika::detail::variant>, std::decay>,
-                std::exception_ptr>>;
+        using error_type = pika::util::detail::unique_t<pika::util::detail::prepend_t<
+            pika::util::detail::transform_t<predecessor_error_types<pika::detail::variant>,
+                std::decay>,
+            std::exception_ptr>>;
 #else
         // value and error_types of the predecessor sender
-        template <template <typename...> class Tuple,
-            template <typename...> class Variant>
-        using predecessor_value_types =
-            typename pika::execution::experimental::sender_traits<
-                Sender>::template value_types<Tuple, Variant>;
+        template <template <typename...> class Tuple, template <typename...> class Variant>
+        using predecessor_value_types = typename pika::execution::experimental::sender_traits<
+            Sender>::template value_types<Tuple, Variant>;
 
         template <template <typename...> class Variant>
-        using predecessor_error_types =
-            typename pika::execution::experimental::sender_traits<
-                Sender>::template error_types<Variant>;
+        using predecessor_error_types = typename pika::execution::experimental::sender_traits<
+            Sender>::template error_types<Variant>;
 
         // The type of the single void or non-void result that we store. If
         // there are multiple variants or multiple values sync_wait will
         // fail to compile.
-        using result_type =
-            std::decay_t<pika::execution::experimental::detail::single_result_t<
-                predecessor_value_types<pika::util::detail::pack,
-                    pika::util::detail::pack>>>;
+        using result_type = std::decay_t<pika::execution::experimental::detail::single_result_t<
+            predecessor_value_types<pika::util::detail::pack, pika::util::detail::pack>>>;
 
         // Constant to indicate if the type of the result from the
         // predecessor sender is void or not
@@ -132,16 +118,14 @@ namespace pika::sync_wait_detail {
 
         // The type of the value to store in the variant, void_value_type if
         // result_type is void, or result_type if it is not
-        using value_type =
-            std::conditional_t<is_void_result, void_value_type, result_type>;
+        using value_type = std::conditional_t<is_void_result, void_value_type, result_type>;
 
         // The type of errors to store in the variant. This in itself is a
         // variant.
-        using error_type =
-            pika::util::detail::unique_t<pika::util::detail::prepend_t<
-                pika::util::detail::transform_t<
-                    predecessor_error_types<pika::detail::variant>, std::decay>,
-                std::exception_ptr>>;
+        using error_type = pika::util::detail::unique_t<pika::util::detail::prepend_t<
+            pika::util::detail::transform_t<predecessor_error_types<pika::detail::variant>,
+                std::decay>,
+            std::exception_ptr>>;
 #endif
 
         // We use a spinlock here to allow taking the lock on non-pika threads.
@@ -152,9 +136,7 @@ namespace pika::sync_wait_detail {
             pika::condition_variable cond_var;
             mutex_type mtx;
             std::atomic<bool> set_called = false;
-            pika::detail::variant<pika::detail::monostate, error_type,
-                value_type>
-                value;
+            pika::detail::variant<pika::detail::monostate, error_type, value_type> value;
 
             void wait()
             {
@@ -183,8 +165,8 @@ namespace pika::sync_wait_detail {
                 }
                 else if (pika::detail::holds_alternative<error_type>(value))
                 {
-                    pika::detail::visit(sync_wait_error_visitor{},
-                        pika::detail::get<error_type>(value));
+                    pika::detail::visit(
+                        sync_wait_error_visitor{}, pika::detail::get<error_type>(value));
                 }
 
                 // If the variant holds a pika::detail::monostate something has gone
@@ -199,8 +181,7 @@ namespace pika::sync_wait_detail {
         {
             std::unique_lock<mutex_type> l(state.mtx);
             state.set_called = true;
-            [[maybe_unused]] pika::util::ignore_while_checking<decltype(l)> il(
-                &l);
+            [[maybe_unused]] pika::util::ignore_while_checking<decltype(l)> il(&l);
 
             state.cond_var.notify_one();
         }
@@ -209,21 +190,19 @@ namespace pika::sync_wait_detail {
         friend void tag_invoke(pika::execution::experimental::set_error_t,
             sync_wait_receiver_type&& r, Error&& error) noexcept
         {
-            r.state.value.template emplace<error_type>(
-                PIKA_FORWARD(Error, error));
+            r.state.value.template emplace<error_type>(PIKA_FORWARD(Error, error));
             r.signal_set_called();
         }
 
-        friend void tag_invoke(pika::execution::experimental::set_stopped_t,
-            sync_wait_receiver_type&& r) noexcept
+        friend void tag_invoke(
+            pika::execution::experimental::set_stopped_t, sync_wait_receiver_type&& r) noexcept
         {
             r.signal_set_called();
         }
 
         template <typename... Us,
-            typename =
-                std::enable_if_t<(is_void_result && sizeof...(Us) == 0) ||
-                    (!is_void_result && sizeof...(Us) == 1)>>
+            typename = std::enable_if_t<(is_void_result && sizeof...(Us) == 0) ||
+                (!is_void_result && sizeof...(Us) == 1)>>
         friend void tag_invoke(pika::execution::experimental::set_value_t,
             sync_wait_receiver_type&& r, Us&&... us) noexcept
         {
@@ -231,9 +210,8 @@ namespace pika::sync_wait_detail {
             r.signal_set_called();
         }
 
-        friend constexpr pika::execution::experimental::detail::empty_env
-        tag_invoke(pika::execution::experimental::get_env_t,
-            sync_wait_receiver_type const&) noexcept
+        friend constexpr pika::execution::experimental::empty_env tag_invoke(
+            pika::execution::experimental::get_env_t, sync_wait_receiver_type const&) noexcept
         {
             return {};
         }
@@ -241,8 +219,7 @@ namespace pika::sync_wait_detail {
 }    // namespace pika::sync_wait_detail
 
 namespace pika::this_thread::experimental {
-    inline constexpr struct sync_wait_t final
-      : pika::functional::detail::tag_fallback<sync_wait_t>
+    inline constexpr struct sync_wait_t final : pika::functional::detail::tag_fallback<sync_wait_t>
     {
     private:
         // clang-format off
@@ -251,8 +228,7 @@ namespace pika::this_thread::experimental {
                 pika::execution::experimental::is_sender_v<Sender>
             )>
         // clang-format on
-        friend constexpr PIKA_FORCEINLINE auto
-        tag_fallback_invoke(sync_wait_t, Sender&& sender)
+        friend constexpr PIKA_FORCEINLINE auto tag_fallback_invoke(sync_wait_t, Sender&& sender)
         {
             using receiver_type = sync_wait_detail::sync_wait_receiver<Sender>;
             using state_type = typename receiver_type::shared_state;
