@@ -38,8 +38,8 @@ namespace pika::execution {
 
         /// The type of the associated executor parameters object which is
         /// associated with this execution policy
-        typedef parallel::execution::extract_executor_parameters<
-            executor_type>::type executor_parameters_type;
+        typedef parallel::execution::extract_executor_parameters<executor_type>::type
+            executor_parameters_type;
 
         /// The category of the execution agents created by this execution
         /// policy.
@@ -92,16 +92,15 @@ namespace pika::execution {
         /// \returns The new simd_task_policy
         ///
         template <typename Executor>
-        typename parallel::execution::rebind_executor<simd_task_policy,
-            Executor, executor_parameters_type>::type
+        typename parallel::execution::rebind_executor<simd_task_policy, Executor,
+            executor_parameters_type>::type
         on(Executor&& exec) const
         {
             static_assert(pika::traits::is_executor_any<Executor>::value,
                 "pika::traits::is_executor_any<Executor>::value");
 
-            typedef
-                typename parallel::execution::rebind_executor<simd_task_policy,
-                    Executor, executor_parameters_type>::type rebound_type;
+            typedef typename parallel::execution::rebind_executor<simd_task_policy, Executor,
+                executor_parameters_type>::type rebound_type;
             return rebound_type(PIKA_FORWARD(Executor, exec), parameters());
         }
 
@@ -121,18 +120,16 @@ namespace pika::execution {
         /// \returns The new simd_task_policy
         ///
         template <typename... Parameters,
-            typename ParametersType = typename parallel::execution::
-                executor_parameters_join<Parameters...>::type>
-        typename parallel::execution::rebind_executor<simd_task_policy,
-            executor_type, ParametersType>::type
+            typename ParametersType =
+                typename parallel::execution::executor_parameters_join<Parameters...>::type>
+        typename parallel::execution::rebind_executor<simd_task_policy, executor_type,
+            ParametersType>::type
         with(Parameters&&... params) const
         {
-            typedef
-                typename parallel::execution::rebind_executor<simd_task_policy,
-                    executor_type, ParametersType>::type rebound_type;
+            typedef typename parallel::execution::rebind_executor<simd_task_policy, executor_type,
+                ParametersType>::type rebound_type;
             return rebound_type(executor(),
-                parallel::execution::join_executor_parameters(
-                    PIKA_FORWARD(Parameters, params)...));
+                parallel::execution::join_executor_parameters(PIKA_FORWARD(Parameters, params)...));
         }
 
         using base_policy_type = sequenced_task_policy;
@@ -191,8 +188,8 @@ namespace pika::execution {
 
         /// The category of the execution agents created by this execution
         /// policy.
-        typedef typename pika::traits::executor_execution_category<
-            executor_type>::type execution_category;
+        typedef typename pika::traits::executor_execution_category<executor_type>::type
+            execution_category;
 
         /// Rebind the type of executor used by this execution policy. The
         /// execution category of Executor shall not be weaker than that of
@@ -237,15 +234,14 @@ namespace pika::execution {
         /// \returns The new simd_task_policy_shim
         ///
         template <typename Executor_>
-        typename parallel::execution::rebind_executor<simd_task_policy_shim,
-            Executor_, executor_parameters_type>::type
+        typename parallel::execution::rebind_executor<simd_task_policy_shim, Executor_,
+            executor_parameters_type>::type
         on(Executor_&& exec) const
         {
             static_assert(pika::traits::is_executor_any<Executor_>::value,
                 "pika::traits::is_executor_any<Executor_>::value");
 
-            typedef typename parallel::execution::rebind_executor<
-                simd_task_policy_shim, Executor_,
+            typedef typename parallel::execution::rebind_executor<simd_task_policy_shim, Executor_,
                 executor_parameters_type>::type rebound_type;
             return rebound_type(PIKA_FORWARD(Executor_, exec), params_);
         }
@@ -266,22 +262,20 @@ namespace pika::execution {
         /// \returns The new sequenced_task_policy_shim
         ///
         template <typename... Parameters_,
-            typename ParametersType = typename parallel::execution::
-                executor_parameters_join<Parameters_...>::type>
-        typename parallel::execution::rebind_executor<simd_task_policy_shim,
-            executor_type, ParametersType>::type
+            typename ParametersType =
+                typename parallel::execution::executor_parameters_join<Parameters_...>::type>
+        typename parallel::execution::rebind_executor<simd_task_policy_shim, executor_type,
+            ParametersType>::type
         with(Parameters_&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<
-                simd_task_policy_shim, executor_type, ParametersType>::type
-                rebound_type;
+            typedef typename parallel::execution::rebind_executor<simd_task_policy_shim,
+                executor_type, ParametersType>::type rebound_type;
             return rebound_type(exec_,
                 parallel::execution::join_executor_parameters(
                     PIKA_FORWARD(Parameters_, params)...));
         }
 
-        using base_policy_type =
-            sequenced_task_policy_shim<Executor, Parameters>;
+        using base_policy_type = sequenced_task_policy_shim<Executor, Parameters>;
         base_policy_type base_policy()
         {
             return simd_task_policy_shim<Executor, Parameters>(exec_, params_);
@@ -336,8 +330,8 @@ namespace pika::execution {
 
         /// The type of the associated executor parameters object which is
         /// associated with this execution policy
-        typedef parallel::execution::extract_executor_parameters<
-            executor_type>::type executor_parameters_type;
+        typedef parallel::execution::extract_executor_parameters<executor_type>::type
+            executor_parameters_type;
 
         /// The category of the execution agents created by this execution
         /// policy.
@@ -400,8 +394,8 @@ namespace pika::execution {
             static_assert(pika::traits::is_executor_any<Executor>::value,
                 "pika::traits::is_executor_any<Executor>::value");
 
-            typedef typename parallel::execution::rebind_executor<simd_policy,
-                Executor, executor_parameters_type>::type rebound_type;
+            typedef typename parallel::execution::rebind_executor<simd_policy, Executor,
+                executor_parameters_type>::type rebound_type;
             return rebound_type(PIKA_FORWARD(Executor, exec), parameters());
         }
 
@@ -421,17 +415,16 @@ namespace pika::execution {
         /// \returns The new simd_policy
         ///
         template <typename... Parameters,
-            typename ParametersType = typename parallel::execution::
-                executor_parameters_join<Parameters...>::type>
-        typename parallel::execution::rebind_executor<simd_policy,
-            executor_type, ParametersType>::type
+            typename ParametersType =
+                typename parallel::execution::executor_parameters_join<Parameters...>::type>
+        typename parallel::execution::rebind_executor<simd_policy, executor_type,
+            ParametersType>::type
         with(Parameters&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<simd_policy,
-                executor_type, ParametersType>::type rebound_type;
+            typedef typename parallel::execution::rebind_executor<simd_policy, executor_type,
+                ParametersType>::type rebound_type;
             return rebound_type(executor(),
-                parallel::execution::join_executor_parameters(
-                    PIKA_FORWARD(Parameters, params)...));
+                parallel::execution::join_executor_parameters(PIKA_FORWARD(Parameters, params)...));
         }
 
         using base_policy_type = sequenced_policy;
@@ -487,8 +480,8 @@ namespace pika::execution {
 
         /// The category of the execution agents created by this execution
         /// policy.
-        typedef typename pika::traits::executor_execution_category<
-            executor_type>::type execution_category;
+        typedef typename pika::traits::executor_execution_category<executor_type>::type
+            execution_category;
 
         /// Rebind the type of executor used by this execution policy. The
         /// execution category of Executor shall not be weaker than that of
@@ -507,8 +500,7 @@ namespace pika::execution {
         ///
         /// \returns The new simd_task_policy_shim
         ///
-        constexpr simd_task_policy_shim<Executor, Parameters> operator()(
-            task_policy_tag) const
+        constexpr simd_task_policy_shim<Executor, Parameters> operator()(task_policy_tag) const
         {
             return simd_task_policy_shim<Executor, Parameters>(exec_, params_);
         }
@@ -537,16 +529,15 @@ namespace pika::execution {
         /// \returns The new simd_policy
         ///
         template <typename Executor_>
-        typename parallel::execution::rebind_executor<simd_policy_shim,
-            Executor_, executor_parameters_type>::type
+        typename parallel::execution::rebind_executor<simd_policy_shim, Executor_,
+            executor_parameters_type>::type
         on(Executor_&& exec) const
         {
             static_assert(pika::traits::is_executor_any<Executor_>::value,
                 "pika::traits::is_executor_any<Executor_>::value");
 
-            typedef
-                typename parallel::execution::rebind_executor<simd_policy_shim,
-                    Executor_, executor_parameters_type>::type rebound_type;
+            typedef typename parallel::execution::rebind_executor<simd_policy_shim, Executor_,
+                executor_parameters_type>::type rebound_type;
             return rebound_type(PIKA_FORWARD(Executor_, exec), params_);
         }
 
@@ -566,15 +557,14 @@ namespace pika::execution {
         /// \returns The new simd_policy_shim
         ///
         template <typename... Parameters_,
-            typename ParametersType = typename parallel::execution::
-                executor_parameters_join<Parameters_...>::type>
-        typename parallel::execution::rebind_executor<simd_policy_shim,
-            executor_type, ParametersType>::type
+            typename ParametersType =
+                typename parallel::execution::executor_parameters_join<Parameters_...>::type>
+        typename parallel::execution::rebind_executor<simd_policy_shim, executor_type,
+            ParametersType>::type
         with(Parameters_&&... params) const
         {
-            typedef
-                typename parallel::execution::rebind_executor<simd_policy_shim,
-                    executor_type, ParametersType>::type rebound_type;
+            typedef typename parallel::execution::rebind_executor<simd_policy_shim, executor_type,
+                ParametersType>::type rebound_type;
             return rebound_type(exec_,
                 parallel::execution::join_executor_parameters(
                     PIKA_FORWARD(Parameters_, params)...));
@@ -639,8 +629,8 @@ namespace pika::execution {
 
         /// The type of the associated executor parameters object which is
         /// associated with this execution policy
-        typedef parallel::execution::extract_executor_parameters<
-            executor_type>::type executor_parameters_type;
+        typedef parallel::execution::extract_executor_parameters<executor_type>::type
+            executor_parameters_type;
 
         /// The category of the execution agents created by this execution
         /// policy.
@@ -692,16 +682,15 @@ namespace pika::execution {
         /// \returns The new par_simd_task_policy
         ///
         template <typename Executor>
-        typename parallel::execution::rebind_executor<par_simd_task_policy,
-            Executor, executor_parameters_type>::type
+        typename parallel::execution::rebind_executor<par_simd_task_policy, Executor,
+            executor_parameters_type>::type
         on(Executor&& exec) const
         {
             static_assert(pika::traits::is_executor_any<Executor>::value,
                 "pika::traits::is_executor_any<Executor>::value");
 
-            typedef typename parallel::execution::rebind_executor<
-                par_simd_task_policy, Executor, executor_parameters_type>::type
-                rebound_type;
+            typedef typename parallel::execution::rebind_executor<par_simd_task_policy, Executor,
+                executor_parameters_type>::type rebound_type;
             return rebound_type(PIKA_FORWARD(Executor, exec), parameters());
         }
 
@@ -721,18 +710,16 @@ namespace pika::execution {
         /// \returns The new par_simd_policy_shim
         ///
         template <typename... Parameters,
-            typename ParametersType = typename parallel::execution::
-                executor_parameters_join<Parameters...>::type>
-        typename parallel::execution::rebind_executor<par_simd_task_policy,
-            executor_type, ParametersType>::type
+            typename ParametersType =
+                typename parallel::execution::executor_parameters_join<Parameters...>::type>
+        typename parallel::execution::rebind_executor<par_simd_task_policy, executor_type,
+            ParametersType>::type
         with(Parameters&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<
-                par_simd_task_policy, executor_type, ParametersType>::type
-                rebound_type;
+            typedef typename parallel::execution::rebind_executor<par_simd_task_policy,
+                executor_type, ParametersType>::type rebound_type;
             return rebound_type(executor(),
-                parallel::execution::join_executor_parameters(
-                    PIKA_FORWARD(Parameters, params)...));
+                parallel::execution::join_executor_parameters(PIKA_FORWARD(Parameters, params)...));
         }
 
         using base_policy_type = parallel_task_policy;
@@ -780,8 +767,8 @@ namespace pika::execution {
 
         /// The type of the associated executor parameters object which is
         /// associated with this execution policy
-        typedef parallel::execution::extract_executor_parameters<
-            executor_type>::type executor_parameters_type;
+        typedef parallel::execution::extract_executor_parameters<executor_type>::type
+            executor_parameters_type;
 
         /// The category of the execution agents created by this execution
         /// policy.
@@ -839,9 +826,8 @@ namespace pika::execution {
             static_assert(pika::traits::is_executor_any<Executor>::value,
                 "pika::traits::is_executor_any<Executor>::value");
 
-            typedef
-                typename parallel::execution::rebind_executor<par_simd_policy,
-                    Executor, executor_parameters_type>::type rebound_type;
+            typedef typename parallel::execution::rebind_executor<par_simd_policy, Executor,
+                executor_parameters_type>::type rebound_type;
             return rebound_type(PIKA_FORWARD(Executor, exec), parameters());
         }
 
@@ -860,18 +846,16 @@ namespace pika::execution {
         /// \returns The new par_simd_policy
         ///
         template <typename... Parameters,
-            typename ParametersType = typename parallel::execution::
-                executor_parameters_join<Parameters...>::type>
-        typename parallel::execution::rebind_executor<par_simd_policy,
-            executor_type, ParametersType>::type
+            typename ParametersType =
+                typename parallel::execution::executor_parameters_join<Parameters...>::type>
+        typename parallel::execution::rebind_executor<par_simd_policy, executor_type,
+            ParametersType>::type
         with(Parameters&&... params) const
         {
-            typedef
-                typename parallel::execution::rebind_executor<par_simd_policy,
-                    executor_type, ParametersType>::type rebound_type;
+            typedef typename parallel::execution::rebind_executor<par_simd_policy, executor_type,
+                ParametersType>::type rebound_type;
             return rebound_type(executor(),
-                parallel::execution::join_executor_parameters(
-                    PIKA_FORWARD(Parameters, params)...));
+                parallel::execution::join_executor_parameters(PIKA_FORWARD(Parameters, params)...));
         }
 
         using base_policy_type = parallel_policy;
@@ -926,8 +910,8 @@ namespace pika::execution {
 
         /// The category of the execution agents created by this execution
         /// policy.
-        typedef typename pika::traits::executor_execution_category<
-            executor_type>::type execution_category;
+        typedef typename pika::traits::executor_execution_category<executor_type>::type
+            execution_category;
 
         /// Rebind the type of executor used by this execution policy. The
         /// execution category of Executor shall not be weaker than that of
@@ -946,11 +930,9 @@ namespace pika::execution {
         ///
         /// \returns The new par_simd_task_policy_shim
         ///
-        constexpr par_simd_task_policy_shim<Executor, Parameters> operator()(
-            task_policy_tag) const
+        constexpr par_simd_task_policy_shim<Executor, Parameters> operator()(task_policy_tag) const
         {
-            return par_simd_task_policy_shim<Executor, Parameters>(
-                exec_, params_);
+            return par_simd_task_policy_shim<Executor, Parameters>(exec_, params_);
         }
 
         /// Create a new non task policy from itself
@@ -977,16 +959,15 @@ namespace pika::execution {
         /// \returns The new parallel_policy
         ///
         template <typename Executor_>
-        typename parallel::execution::rebind_executor<par_simd_policy_shim,
-            Executor_, executor_parameters_type>::type
+        typename parallel::execution::rebind_executor<par_simd_policy_shim, Executor_,
+            executor_parameters_type>::type
         on(Executor_&& exec) const
         {
             static_assert(pika::traits::is_executor_any<Executor_>::value,
                 "pika::traits::is_executor_any<Executor_>::value");
 
-            typedef typename parallel::execution::rebind_executor<
-                par_simd_policy_shim, Executor_, executor_parameters_type>::type
-                rebound_type;
+            typedef typename parallel::execution::rebind_executor<par_simd_policy_shim, Executor_,
+                executor_parameters_type>::type rebound_type;
             return rebound_type(PIKA_FORWARD(Executor_, exec), params_);
         }
 
@@ -1005,15 +986,14 @@ namespace pika::execution {
         /// \returns The new par_simd_policy_shim
         ///
         template <typename... Parameters_,
-            typename ParametersType = typename parallel::execution::
-                executor_parameters_join<Parameters_...>::type>
-        typename parallel::execution::rebind_executor<par_simd_policy_shim,
-            executor_type, ParametersType>::type
+            typename ParametersType =
+                typename parallel::execution::executor_parameters_join<Parameters_...>::type>
+        typename parallel::execution::rebind_executor<par_simd_policy_shim, executor_type,
+            ParametersType>::type
         with(Parameters_&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<
-                par_simd_policy_shim, executor_type, ParametersType>::type
-                rebound_type;
+            typedef typename parallel::execution::rebind_executor<par_simd_policy_shim,
+                executor_type, ParametersType>::type rebound_type;
             return rebound_type(exec_,
                 parallel::execution::join_executor_parameters(
                     PIKA_FORWARD(Parameters_, params)...));
@@ -1080,8 +1060,8 @@ namespace pika::execution {
 
         /// The category of the execution agents created by this execution
         /// policy.
-        typedef typename pika::traits::executor_execution_category<
-            executor_type>::type execution_category;
+        typedef typename pika::traits::executor_execution_category<executor_type>::type
+            execution_category;
 
         /// Rebind the type of executor used by this execution policy. The
         /// execution category of Executor shall not be weaker than that of
@@ -1126,16 +1106,15 @@ namespace pika::execution {
         /// \returns The new parallel_task_policy
         ///
         template <typename Executor_>
-        typename parallel::execution::rebind_executor<par_simd_task_policy_shim,
-            Executor_, executor_parameters_type>::type
+        typename parallel::execution::rebind_executor<par_simd_task_policy_shim, Executor_,
+            executor_parameters_type>::type
         on(Executor_&& exec) const
         {
             static_assert(pika::traits::is_executor_any<Executor_>::value,
                 "pika::traits::is_executor_any<Executor_>::value");
 
-            typedef typename parallel::execution::rebind_executor<
-                par_simd_task_policy_shim, Executor_,
-                executor_parameters_type>::type rebound_type;
+            typedef typename parallel::execution::rebind_executor<par_simd_task_policy_shim,
+                Executor_, executor_parameters_type>::type rebound_type;
             return rebound_type(PIKA_FORWARD(Executor_, exec), params_);
         }
 
@@ -1155,26 +1134,23 @@ namespace pika::execution {
         /// \returns The new parallel_policy_shim
         ///
         template <typename... Parameters_,
-            typename ParametersType = typename parallel::execution::
-                executor_parameters_join<Parameters_...>::type>
-        typename parallel::execution::rebind_executor<par_simd_task_policy_shim,
-            executor_type, ParametersType>::type
+            typename ParametersType =
+                typename parallel::execution::executor_parameters_join<Parameters_...>::type>
+        typename parallel::execution::rebind_executor<par_simd_task_policy_shim, executor_type,
+            ParametersType>::type
         with(Parameters_&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<
-                par_simd_task_policy_shim, executor_type, ParametersType>::type
-                rebound_type;
+            typedef typename parallel::execution::rebind_executor<par_simd_task_policy_shim,
+                executor_type, ParametersType>::type rebound_type;
             return rebound_type(exec_,
                 parallel::execution::join_executor_parameters(
                     PIKA_FORWARD(Parameters_, params)...));
         }
 
-        using base_policy_type =
-            parallel_task_policy_shim<Executor, Parameters>;
+        using base_policy_type = parallel_task_policy_shim<Executor, Parameters>;
         base_policy_type base_policy()
         {
-            return parallel_task_policy_shim<Executor, Parameters>(
-                exec_, params_);
+            return parallel_task_policy_shim<Executor, Parameters>(exec_, params_);
         }
 
         /// Return the associated executor object.
@@ -1203,8 +1179,7 @@ namespace pika::execution {
         constexpr par_simd_task_policy_shim() = default;
 
         template <typename Executor_, typename Parameters_>
-        constexpr par_simd_task_policy_shim(
-            Executor_&& exec, Parameters_&& params)
+        constexpr par_simd_task_policy_shim(Executor_&& exec, Parameters_&& params)
           : exec_(PIKA_FORWARD(Executor_, exec))
           , params_(PIKA_FORWARD(Parameters_, params))
         {
@@ -1216,34 +1191,28 @@ namespace pika::execution {
         /// \endcond
     };
 
-    decltype(auto) simd_task_policy::operator()(
-        non_task_policy_tag /*tag*/) const
+    decltype(auto) simd_task_policy::operator()(non_task_policy_tag /*tag*/) const
     {
         return simd.on(executor()).with(parameters());
     }
 
-    decltype(auto) par_simd_task_policy::operator()(
-        non_task_policy_tag /*tag*/) const
+    decltype(auto) par_simd_task_policy::operator()(non_task_policy_tag /*tag*/) const
     {
         return par_simd.on(executor()).with(parameters());
     }
 
     template <typename Executor, typename Parameters>
-    decltype(auto) simd_task_policy_shim<Executor, Parameters>::operator()(
-        non_task_policy_tag /*tag*/) const
+    decltype(auto)
+    simd_task_policy_shim<Executor, Parameters>::operator()(non_task_policy_tag /*tag*/) const
     {
-        return simd_policy_shim<Executor, Parameters>{}
-            .on(executor())
-            .with(parameters());
+        return simd_policy_shim<Executor, Parameters>{}.on(executor()).with(parameters());
     }
 
     template <typename Executor, typename Parameters>
-    decltype(auto) par_simd_task_policy_shim<Executor, Parameters>::operator()(
-        non_task_policy_tag /*tag*/) const
+    decltype(auto)
+    par_simd_task_policy_shim<Executor, Parameters>::operator()(non_task_policy_tag /*tag*/) const
     {
-        return par_simd_policy_shim<Executor, Parameters>{}
-            .on(executor())
-            .with(parameters());
+        return par_simd_policy_shim<Executor, Parameters>{}.on(executor()).with(parameters());
     }
 }    // namespace pika::execution
 
@@ -1258,47 +1227,40 @@ namespace pika::detail {
     };
 
     template <typename Executor, typename Parameters>
-    struct is_execution_policy<
-        pika::execution::simd_policy_shim<Executor, Parameters>>
+    struct is_execution_policy<pika::execution::simd_policy_shim<Executor, Parameters>>
       : std::true_type
     {
     };
 
     template <>
-    struct is_execution_policy<pika::execution::simd_task_policy>
-      : std::true_type
+    struct is_execution_policy<pika::execution::simd_task_policy> : std::true_type
     {
     };
 
     template <typename Executor, typename Parameters>
-    struct is_execution_policy<
-        pika::execution::simd_task_policy_shim<Executor, Parameters>>
+    struct is_execution_policy<pika::execution::simd_task_policy_shim<Executor, Parameters>>
       : std::true_type
     {
     };
 
     template <>
-    struct is_execution_policy<pika::execution::par_simd_policy>
-      : std::true_type
+    struct is_execution_policy<pika::execution::par_simd_policy> : std::true_type
     {
     };
 
     template <typename Executor, typename Parameters>
-    struct is_execution_policy<
-        pika::execution::par_simd_policy_shim<Executor, Parameters>>
+    struct is_execution_policy<pika::execution::par_simd_policy_shim<Executor, Parameters>>
       : std::true_type
     {
     };
 
     template <>
-    struct is_execution_policy<pika::execution::par_simd_task_policy>
-      : std::true_type
+    struct is_execution_policy<pika::execution::par_simd_task_policy> : std::true_type
     {
     };
 
     template <typename Executor, typename Parameters>
-    struct is_execution_policy<
-        pika::execution::par_simd_task_policy_shim<Executor, Parameters>>
+    struct is_execution_policy<pika::execution::par_simd_task_policy_shim<Executor, Parameters>>
       : std::true_type
     {
     };
@@ -1307,28 +1269,24 @@ namespace pika::detail {
     ///////////////////////////////////////////////////////////////////////////
     /// \cond NOINTERNAL
     template <>
-    struct is_sequenced_execution_policy<pika::execution::simd_policy>
-      : std::true_type
+    struct is_sequenced_execution_policy<pika::execution::simd_policy> : std::true_type
     {
     };
 
     template <>
-    struct is_sequenced_execution_policy<pika::execution::simd_task_policy>
+    struct is_sequenced_execution_policy<pika::execution::simd_task_policy> : std::true_type
+    {
+    };
+
+    template <typename Executor, typename Parameters>
+    struct is_sequenced_execution_policy<pika::execution::simd_policy_shim<Executor, Parameters>>
       : std::true_type
     {
     };
 
     template <typename Executor, typename Parameters>
     struct is_sequenced_execution_policy<
-        pika::execution::simd_policy_shim<Executor, Parameters>>
-      : std::true_type
-    {
-    };
-
-    template <typename Executor, typename Parameters>
-    struct is_sequenced_execution_policy<
-        pika::execution::simd_task_policy_shim<Executor, Parameters>>
-      : std::true_type
+        pika::execution::simd_task_policy_shim<Executor, Parameters>> : std::true_type
     {
     };
     /// \endcond
@@ -1336,28 +1294,24 @@ namespace pika::detail {
     ///////////////////////////////////////////////////////////////////////////
     /// \cond NOINTERNAL
     template <>
-    struct is_async_execution_policy<pika::execution::simd_task_policy>
-      : std::true_type
+    struct is_async_execution_policy<pika::execution::simd_task_policy> : std::true_type
     {
     };
 
     template <typename Executor, typename Parameters>
-    struct is_async_execution_policy<
-        pika::execution::simd_task_policy_shim<Executor, Parameters>>
+    struct is_async_execution_policy<pika::execution::simd_task_policy_shim<Executor, Parameters>>
       : std::true_type
     {
     };
 
     template <>
-    struct is_async_execution_policy<pika::execution::par_simd_task_policy>
-      : std::true_type
+    struct is_async_execution_policy<pika::execution::par_simd_task_policy> : std::true_type
     {
     };
 
     template <typename Executor, typename Parameters>
     struct is_async_execution_policy<
-        pika::execution::par_simd_task_policy_shim<Executor, Parameters>>
-      : std::true_type
+        pika::execution::par_simd_task_policy_shim<Executor, Parameters>> : std::true_type
     {
     };
     /// \endcond
@@ -1365,28 +1319,24 @@ namespace pika::detail {
     ///////////////////////////////////////////////////////////////////////////
     /// \cond NOINTERNAL
     template <>
-    struct is_parallel_execution_policy<pika::execution::par_simd_policy>
-      : std::true_type
+    struct is_parallel_execution_policy<pika::execution::par_simd_policy> : std::true_type
     {
     };
 
     template <>
-    struct is_parallel_execution_policy<pika::execution::par_simd_task_policy>
+    struct is_parallel_execution_policy<pika::execution::par_simd_task_policy> : std::true_type
+    {
+    };
+
+    template <typename Executor, typename Parameters>
+    struct is_parallel_execution_policy<pika::execution::par_simd_policy_shim<Executor, Parameters>>
       : std::true_type
     {
     };
 
     template <typename Executor, typename Parameters>
     struct is_parallel_execution_policy<
-        pika::execution::par_simd_policy_shim<Executor, Parameters>>
-      : std::true_type
-    {
-    };
-
-    template <typename Executor, typename Parameters>
-    struct is_parallel_execution_policy<
-        pika::execution::par_simd_task_policy_shim<Executor, Parameters>>
-      : std::true_type
+        pika::execution::par_simd_task_policy_shim<Executor, Parameters>> : std::true_type
     {
     };
     /// \endcond
@@ -1394,54 +1344,46 @@ namespace pika::detail {
     ///////////////////////////////////////////////////////////////////////////
     /// \cond NOINTERNAL
     template <>
-    struct is_vectorpack_execution_policy<pika::execution::simd_policy>
-      : std::true_type
+    struct is_vectorpack_execution_policy<pika::execution::simd_policy> : std::true_type
     {
     };
 
     template <>
-    struct is_vectorpack_execution_policy<pika::execution::simd_task_policy>
+    struct is_vectorpack_execution_policy<pika::execution::simd_task_policy> : std::true_type
+    {
+    };
+
+    template <typename Executor, typename Parameters>
+    struct is_vectorpack_execution_policy<pika::execution::simd_policy_shim<Executor, Parameters>>
       : std::true_type
     {
     };
 
     template <typename Executor, typename Parameters>
     struct is_vectorpack_execution_policy<
-        pika::execution::simd_policy_shim<Executor, Parameters>>
-      : std::true_type
-    {
-    };
-
-    template <typename Executor, typename Parameters>
-    struct is_vectorpack_execution_policy<
-        pika::execution::simd_task_policy_shim<Executor, Parameters>>
-      : std::true_type
+        pika::execution::simd_task_policy_shim<Executor, Parameters>> : std::true_type
     {
     };
 
     template <>
-    struct is_vectorpack_execution_policy<pika::execution::par_simd_policy>
-      : std::true_type
+    struct is_vectorpack_execution_policy<pika::execution::par_simd_policy> : std::true_type
     {
     };
 
     template <>
-    struct is_vectorpack_execution_policy<pika::execution::par_simd_task_policy>
-      : std::true_type
+    struct is_vectorpack_execution_policy<pika::execution::par_simd_task_policy> : std::true_type
     {
     };
 
     template <typename Executor, typename Parameters>
     struct is_vectorpack_execution_policy<
-        pika::execution::par_simd_policy_shim<Executor, Parameters>>
-      : std::true_type
+        pika::execution::par_simd_policy_shim<Executor, Parameters>> : std::true_type
     {
     };
 
     template <typename Executor, typename Parameters>
     struct is_vectorpack_execution_policy<
-        pika::execution::par_simd_task_policy_shim<Executor, Parameters>>
-      : std::true_type
+        pika::execution::par_simd_task_policy_shim<Executor, Parameters>> : std::true_type
     {
     };
     /// \endcond
