@@ -12,11 +12,10 @@
 //
 
 #if defined(PIKA_MSVC)
-#pragma warning(disable : 4786)    // identifier truncated in debug info
-#pragma warning(disable : 4710)    // function not inlined
-#pragma warning(                                                               \
-    disable : 4711)    // function selected for automatic inline expansion
-#pragma warning(disable : 4514)    // unreferenced inline removed
+# pragma warning(disable : 4786)    // identifier truncated in debug info
+# pragma warning(disable : 4710)    // function not inlined
+# pragma warning(disable : 4711)    // function selected for automatic inline expansion
+# pragma warning(disable : 4514)    // unreferenced inline removed
 #endif
 
 #include <pika/functional/bind.hpp>
@@ -34,8 +33,7 @@ int main()
 
     pair_type pair(10, 20);
 
-    int const& x =
-        pika::util::detail::bind(&pair_type::first, placeholders::_1)(pair);
+    int const& x = pika::util::detail::bind(&pair_type::first, placeholders::_1)(pair);
 
     PIKA_TEST_EQ(&pair.first, &x);
 
