@@ -22,18 +22,13 @@
 #include <fmt/format.h>
 #include <fmt/ostream.h>
 #include <fmt/printf.h>
+#include <fmt/std.h>
 
 #include <memory>
 #include <ostream>
 #include <type_traits>
 
-#if defined(PIKA_WINDOWS)
-#include <windows.h>
-#else
-#include <pthread.h>
-#endif
-
-namespace pika { namespace util { namespace logging { namespace formatter {
+namespace pika::util::logging::formatter {
 
     thread_id::~thread_id() = default;
 
@@ -41,20 +36,8 @@ namespace pika { namespace util { namespace logging { namespace formatter {
     {
         void operator()(std::ostream& to) const override
         {
-            auto id =
-#if defined(PIKA_WINDOWS)
-                ::GetCurrentThreadId();
-#else
-                pthread_self();
-#endif
-            if constexpr (std::is_pointer_v<decltype(id)>)
-            {
-                fmt::print(to, "{}", fmt::ptr(id));
-            }
-            else
-            {
-                fmt::print(to, "{}", id);
-            }
+            auto id = std::this_thread::get_id();
+            fmt::print(to, "{}", id);
         }
     };
 
@@ -63,4 +46,4 @@ namespace pika { namespace util { namespace logging { namespace formatter {
         return std::unique_ptr<thread_id>(new thread_id_impl());
     }
 
-}}}}    // namespace pika::util::logging::formatter
+}    // namespace pika::util::logging::formatter
