@@ -16,21 +16,16 @@
 namespace pika {
     ///////////////////////////////////////////////////////////////////////////
     /// Retrieve the string value of a configuration entry given by \p key.
-    PIKA_EXPORT std::string get_config_entry(
-        std::string const& key, std::string const& dflt);
+    PIKA_EXPORT std::string get_config_entry(std::string const& key, std::string const& dflt);
     /// Retrieve the integer value of a configuration entry given by \p key.
-    PIKA_EXPORT std::string get_config_entry(
-        std::string const& key, std::size_t dflt);
+    PIKA_EXPORT std::string get_config_entry(std::string const& key, std::size_t dflt);
 
     /// Set the string value of a configuration entry given by \p key.
-    PIKA_EXPORT void set_config_entry(
-        std::string const& key, std::string const& value);
+    PIKA_EXPORT void set_config_entry(std::string const& key, std::string const& value);
     /// Set the integer value of a configuration entry given by \p key.
-    PIKA_EXPORT void set_config_entry(
-        std::string const& key, std::size_t value);
+    PIKA_EXPORT void set_config_entry(std::string const& key, std::size_t value);
 
     /// Set the string value of a configuration entry given by \p key.
     PIKA_EXPORT void set_config_entry_callback(std::string const& key,
-        util::detail::function<void(
-            std::string const&, std::string const&)> const& callback);
+        util::detail::function<void(std::string const&, std::string const&)> const& callback);
 }    // namespace pika
