@@ -1059,16 +1059,16 @@ namespace pika::threads::detail {
         bool dump_suspended_threads(
             std::size_t num_thread, std::int64_t& idle_loop_count, bool running)
         {
-#if !defined(PIKA_HAVE_THREAD_MINIMAL_DEADLOCK_DETECTION)
+#if !defined(PIKA_HAVE_THREAD_DEADLOCK_DETECTION)
             PIKA_UNUSED(num_thread);
             PIKA_UNUSED(idle_loop_count);
             PIKA_UNUSED(running);
             return false;
 #else
-            if (get_minimal_deadlock_detection_enabled())
+            if (get_deadlock_detection_enabled())
             {
                 std::lock_guard<mutex_type> lk(mtx_);
-                return detail::dump_suspended_threads(
+                return pika::threads::detail::dump_suspended_threads(
                     num_thread, thread_map_, idle_loop_count, running);
             }
             return false;
