@@ -14,7 +14,7 @@
 #include <pika/execution_base/sender.hpp>
 #include <pika/execution_base/this_thread.hpp>
 #include <pika/functional/unique_function.hpp>
-#include <pika/synchronization/mutex.hpp>
+#include <pika/synchronization/spinlock.hpp>
 
 #include <atomic>
 #include <exception>
@@ -36,11 +36,12 @@ namespace pika::execution::experimental {
         template <typename T>
         struct async_rw_mutex_shared_state
         {
+            using mutex_type = pika::spinlock;
             using shared_state_ptr_type = std::shared_ptr<async_rw_mutex_shared_state>;
             std::atomic<bool> value_set{false};
             std::optional<T> value{std::nullopt};
             shared_state_ptr_type next_state{nullptr};
-            pika::mutex mtx{};
+            mutex_type mtx{};
             pika::detail::small_vector<
                 pika::util::detail::unique_function<void(shared_state_ptr_type)>, 1>
                 continuations{};
@@ -101,7 +102,7 @@ namespace pika::execution::experimental {
             template <typename F>
             void add_continuation(F&& continuation)
             {
-                std::lock_guard<pika::mutex> l(mtx);
+                std::lock_guard<mutex_type> l(mtx);
                 continuations.emplace_back(PIKA_FORWARD(F, continuation));
             }
         };
@@ -109,9 +110,10 @@ namespace pika::execution::experimental {
         template <>
         struct async_rw_mutex_shared_state<void>
         {
+            using mutex_type = pika::spinlock;
             using shared_state_ptr_type = std::shared_ptr<async_rw_mutex_shared_state>;
             shared_state_ptr_type next_state{nullptr};
-            pika::mutex mtx{};
+            mutex_type mtx{};
             pika::detail::small_vector<
                 pika::util::detail::unique_function<void(shared_state_ptr_type)>, 1>
                 continuations{};
@@ -144,7 +146,7 @@ namespace pika::execution::experimental {
             template <typename F>
             void add_continuation(F&& continuation)
             {
-                std::lock_guard<pika::mutex> l(mtx);
+                std::lock_guard<mutex_type> l(mtx);
                 continuations.emplace_back(PIKA_FORWARD(F, continuation));
             }
         };
@@ -458,6 +460,7 @@ namespace pika::execution::experimental {
                         // add a continuation to be triggered when the previous
                         // state is released.
                         p->add_continuation(PIKA_MOVE(continuation));
+                        os.state.reset();
                         os.prev_state.reset();
                     }
                     else
@@ -653,6 +656,7 @@ namespace pika::execution::experimental {
                         // add a continuation to be triggered when the previous
                         // state is released.
                         p->add_continuation(PIKA_MOVE(continuation));
+                        os.state.reset();
                         os.prev_state.reset();
                     }
                     else
