@@ -138,8 +138,7 @@ namespace pika::detail {
         {
             std::unique_lock<mutex_type> lk(state_change);
 
-            while (state.exclusive || state.exclusive_waiting_blocked ||
-                state.upgrade)
+            while (state.exclusive || state.exclusive_waiting_blocked || state.upgrade)
             {
                 shared_cond.wait(lk);
             }
@@ -152,8 +151,7 @@ namespace pika::detail {
         {
             std::unique_lock<mutex_type> lk(state_change);
 
-            if (state.exclusive || state.exclusive_waiting_blocked ||
-                state.upgrade)
+            if (state.exclusive || state.exclusive_waiting_blocked || state.upgrade)
                 return false;
 
             else
@@ -213,8 +211,8 @@ namespace pika::detail {
         bool try_unlock_shared_and_lock()
         {
             std::unique_lock<mutex_type> lk(state_change);
-            if (!state.exclusive && !state.exclusive_waiting_blocked &&
-                !state.upgrade && state.shared_count == 1)
+            if (!state.exclusive && !state.exclusive_waiting_blocked && !state.upgrade &&
+                state.shared_count == 1)
             {
                 state.shared_count = 0;
                 state.exclusive = true;
