@@ -11,12 +11,12 @@
 
 #if defined(WIN32) || defined(_WIN32) || defined(__WIN32__)
 
-#include <pika/thread_support/set_thread_name.hpp>
+# include <pika/thread_support/set_thread_name.hpp>
 
 namespace pika::detail {
     DWORD const MS_VC_EXCEPTION = 0x406D1388;
 
-#pragma pack(push, 8)
+# pragma pack(push, 8)
     typedef struct tagTHREADNAME_INFO
     {
         DWORD dwType;        // Must be 0x1000.
@@ -24,7 +24,7 @@ namespace pika::detail {
         DWORD dwThreadID;    // Thread ID (-1=caller thread).
         DWORD dwFlags;       // Reserved for future use, must be zero.
     } THREADNAME_INFO;
-#pragma pack(pop)
+# pragma pack(pop)
 
     // Set the name of the thread shown in the Visual Studio debugger
     void set_thread_name(char const* threadName, DWORD dwThreadID)
@@ -37,8 +37,8 @@ namespace pika::detail {
 
         __try
         {
-            RaiseException(MS_VC_EXCEPTION, 0, sizeof(info) / sizeof(ULONG_PTR),
-                (ULONG_PTR*) &info);
+            RaiseException(
+                MS_VC_EXCEPTION, 0, sizeof(info) / sizeof(ULONG_PTR), (ULONG_PTR*) &info);
         }
         __except (EXCEPTION_EXECUTE_HANDLER)
         {
