@@ -11,7 +11,7 @@
 #include <pika/coroutines/thread_enums.hpp>
 #include <pika/modules/errors.hpp>
 #ifdef PIKA_HAVE_VERIFY_LOCKS
-#include <pika/lock_registration/detail/register_locks.hpp>
+# include <pika/lock_registration/detail/register_locks.hpp>
 #endif
 #include <pika/execution_base/this_thread.hpp>
 #include <pika/threading_base/detail/reset_lco_description.hpp>
@@ -25,8 +25,8 @@
 #include <pika/type_support/unused.hpp>
 
 #ifdef PIKA_HAVE_THREAD_BACKTRACE_ON_SUSPENSION
-#include <pika/debugging/backtrace.hpp>
-#include <pika/threading_base/detail/reset_backtrace.hpp>
+# include <pika/debugging/backtrace.hpp>
+# include <pika/threading_base/detail/reset_backtrace.hpp>
 #endif
 
 #include <atomic>
@@ -40,61 +40,51 @@
 namespace pika::threads::detail {
 
     ///////////////////////////////////////////////////////////////////////////
-    thread_state set_thread_state(thread_id_type const& id,
-        thread_schedule_state state, thread_restart_state stateex,
-        execution::thread_priority priority, bool retry_on_active,
+    thread_state set_thread_state(thread_id_type const& id, thread_schedule_state state,
+        thread_restart_state stateex, execution::thread_priority priority, bool retry_on_active,
         error_code& ec)
     {
         if (&ec != &throws)
             ec = make_success_code();
 
-        return set_thread_state(id, state, stateex, priority,
-            execution::thread_schedule_hint(), retry_on_active, ec);
+        return set_thread_state(
+            id, state, stateex, priority, execution::thread_schedule_hint(), retry_on_active, ec);
     }
 
     ///////////////////////////////////////////////////////////////////////////
     thread_id_ref_type set_thread_state(thread_id_type const& id,
-        pika::chrono::steady_time_point const& abs_time,
-        std::atomic<bool>* timer_started, thread_schedule_state state,
-        thread_restart_state stateex, execution::thread_priority priority,
-        bool retry_on_active, error_code& ec)
+        pika::chrono::steady_time_point const& abs_time, std::atomic<bool>* timer_started,
+        thread_schedule_state state, thread_restart_state stateex,
+        execution::thread_priority priority, bool retry_on_active, error_code& ec)
     {
-        return set_thread_state_timed(
-            get_thread_id_data(id)->get_scheduler_base(), abs_time, id, state,
-            stateex, priority, execution::thread_schedule_hint(), timer_started,
+        return set_thread_state_timed(get_thread_id_data(id)->get_scheduler_base(), abs_time, id,
+            state, stateex, priority, execution::thread_schedule_hint(), timer_started,
             retry_on_active, ec);
     }
 
     ///////////////////////////////////////////////////////////////////////////
-    thread_state get_thread_state(
-        thread_id_type const& id, error_code& /* ec */)
+    thread_state get_thread_state(thread_id_type const& id, error_code& /* ec */)
     {
         return id ? get_thread_id_data(id)->get_state() :
-                    thread_state(thread_schedule_state::terminated,
-                        thread_restart_state::unknown);
+                    thread_state(thread_schedule_state::terminated, thread_restart_state::unknown);
     }
 
     ///////////////////////////////////////////////////////////////////////////
     std::size_t get_thread_phase(thread_id_type const& id, error_code& /* ec */)
     {
-        return id ? get_thread_id_data(id)->get_thread_phase() :
-                    std::size_t(~0);
+        return id ? get_thread_id_data(id)->get_thread_phase() : std::size_t(~0);
     }
 
     ///////////////////////////////////////////////////////////////////////////
-    execution::thread_priority get_thread_priority(
-        thread_id_type const& id, error_code& /* ec */)
+    execution::thread_priority get_thread_priority(thread_id_type const& id, error_code& /* ec */)
     {
-        return id ? get_thread_id_data(id)->get_priority() :
-                    execution::thread_priority::unknown;
+        return id ? get_thread_id_data(id)->get_priority() : execution::thread_priority::unknown;
     }
 
-    std::ptrdiff_t get_stack_size(
-        thread_id_type const& id, error_code& /* ec */)
+    std::ptrdiff_t get_stack_size(thread_id_type const& id, error_code& /* ec */)
     {
-        return id ?
-            get_thread_id_data(id)->get_stack_size() :
-            static_cast<std::ptrdiff_t>(execution::thread_stacksize::unknown);
+        return id ? get_thread_id_data(id)->get_stack_size() :
+                    static_cast<std::ptrdiff_t>(execution::thread_stacksize::unknown);
     }
 
     void interrupt_thread(thread_id_type const& id, bool flag, error_code& ec)
@@ -102,8 +92,7 @@ namespace pika::threads::detail {
         if (PIKA_UNLIKELY(!id))
         {
             PIKA_THROWS_IF(ec, pika::error::null_thread_id,
-                "pika::threads::detail::interrupt_thread",
-                "null thread id encountered");
+                "pika::threads::detail::interrupt_thread", "null thread id encountered");
             return;
         }
 
@@ -114,9 +103,8 @@ namespace pika::threads::detail {
 
         // Set thread state to pending. If the thread is currently active we do
         // not retry. The thread will either exit or hit an interruption_point.
-        set_thread_state(id, thread_schedule_state::pending,
-            thread_restart_state::abort, execution::thread_priority::normal,
-            false, ec);
+        set_thread_state(id, thread_schedule_state::pending, thread_restart_state::abort,
+            execution::thread_priority::normal, false, ec);
     }
 
     void interruption_point(thread_id_type const& id, error_code& ec)
@@ -124,8 +112,7 @@ namespace pika::threads::detail {
         if (PIKA_UNLIKELY(!id))
         {
             PIKA_THROWS_IF(ec, pika::error::null_thread_id,
-                "pika::threads::detail::interruption_point",
-                "null thread id encountered");
+                "pika::threads::detail::interruption_point", "null thread id encountered");
             return;
         }
 
@@ -136,8 +123,7 @@ namespace pika::threads::detail {
     }
 
     ///////////////////////////////////////////////////////////////////////////
-    bool get_thread_interruption_enabled(
-        thread_id_type const& id, error_code& ec)
+    bool get_thread_interruption_enabled(thread_id_type const& id, error_code& ec)
     {
         if (PIKA_UNLIKELY(!id))
         {
@@ -153,8 +139,7 @@ namespace pika::threads::detail {
         return get_thread_id_data(id)->interruption_enabled();
     }
 
-    bool set_thread_interruption_enabled(
-        thread_id_type const& id, bool enable, error_code& ec)
+    bool set_thread_interruption_enabled(thread_id_type const& id, bool enable, error_code& ec)
     {
         if (PIKA_UNLIKELY(!id))
         {
@@ -170,8 +155,7 @@ namespace pika::threads::detail {
         return get_thread_id_data(id)->set_interruption_enabled(enable);
     }
 
-    bool get_thread_interruption_requested(
-        thread_id_type const& id, error_code& ec)
+    bool get_thread_interruption_requested(thread_id_type const& id, error_code& ec)
     {
         if (PIKA_UNLIKELY(!id))
         {
@@ -193,22 +177,19 @@ namespace pika::threads::detail {
         if (PIKA_UNLIKELY(!id))
         {
             PIKA_THROWS_IF(ec, pika::error::null_thread_id,
-                "pika::threads::detail::get_thread_data",
-                "null thread id encountered");
+                "pika::threads::detail::get_thread_data", "null thread id encountered");
             return 0;
         }
 
         return get_thread_id_data(id)->get_thread_data();
     }
 
-    std::size_t set_thread_data(
-        thread_id_type const& id, std::size_t data, error_code& ec)
+    std::size_t set_thread_data(thread_id_type const& id, std::size_t data, error_code& ec)
     {
         if (PIKA_UNLIKELY(!id))
         {
             PIKA_THROWS_IF(ec, pika::error::null_thread_id,
-                "pika::threads::detail::set_thread_data",
-                "null thread id encountered");
+                "pika::threads::detail::set_thread_data", "null thread id encountered");
             return 0;
         }
 
@@ -239,8 +220,7 @@ namespace pika::threads::detail {
         if (PIKA_UNLIKELY(!id))
         {
             PIKA_THROWS_IF(ec, pika::error::null_thread_id,
-                "pika::threads::detail::run_thread_exit_callbacks",
-                "null thread id encountered");
+                "pika::threads::detail::run_thread_exit_callbacks", "null thread id encountered");
             return;
         }
 
@@ -250,14 +230,13 @@ namespace pika::threads::detail {
         get_thread_id_data(id)->run_thread_exit_callbacks();
     }
 
-    bool add_thread_exit_callback(thread_id_type const& id,
-        util::detail::function<void()> const& f, error_code& ec)
+    bool add_thread_exit_callback(
+        thread_id_type const& id, util::detail::function<void()> const& f, error_code& ec)
     {
         if (PIKA_UNLIKELY(!id))
         {
             PIKA_THROWS_IF(ec, pika::error::null_thread_id,
-                "pika::threads::detail::add_thread_exit_callback",
-                "null thread id encountered");
+                "pika::threads::detail::add_thread_exit_callback", "null thread id encountered");
             return false;
         }
 
@@ -272,8 +251,7 @@ namespace pika::threads::detail {
         if (PIKA_UNLIKELY(!id))
         {
             PIKA_THROWS_IF(ec, pika::error::null_thread_id,
-                "pika::threads::detail::add_thread_exit_callback",
-                "null thread id encountered");
+                "pika::threads::detail::add_thread_exit_callback", "null thread id encountered");
             return;
         }
 
@@ -287,15 +265,13 @@ namespace pika::threads::detail {
 #ifdef PIKA_HAVE_THREAD_FULLBACKTRACE_ON_SUSPENSION
     char const* get_thread_backtrace(thread_id_type const& id, error_code& ec)
 #else
-    debug::detail::backtrace const* get_thread_backtrace(
-        thread_id_type const& id, error_code& ec)
+    debug::detail::backtrace const* get_thread_backtrace(thread_id_type const& id, error_code& ec)
 #endif
     {
         if (PIKA_UNLIKELY(!id))
         {
             PIKA_THROWS_IF(ec, pika::error::null_thread_id,
-                "pika::threads::detail::get_thread_backtrace",
-                "null thread id encountered");
+                "pika::threads::detail::get_thread_backtrace", "null thread id encountered");
             return nullptr;
         }
 
@@ -306,19 +282,16 @@ namespace pika::threads::detail {
     }
 
 #ifdef PIKA_HAVE_THREAD_FULLBACKTRACE_ON_SUSPENSION
-    char const* set_thread_backtrace(
-        thread_id_type const& id, char const* bt, error_code& ec)
+    char const* set_thread_backtrace(thread_id_type const& id, char const* bt, error_code& ec)
 #else
     debug::detail::backtrace const* set_thread_backtrace(
-        thread_id_type const& id, debug::detail::backtrace const* bt,
-        error_code& ec)
+        thread_id_type const& id, debug::detail::backtrace const* bt, error_code& ec)
 #endif
     {
         if (PIKA_UNLIKELY(!id))
         {
             PIKA_THROWS_IF(ec, pika::error::null_thread_id,
-                "pika::threads::detail::set_thread_backtrace",
-                "null thread id encountered");
+                "pika::threads::detail::set_thread_backtrace", "null thread id encountered");
             return nullptr;
         }
 
@@ -328,13 +301,11 @@ namespace pika::threads::detail {
         return get_thread_id_data(id)->set_backtrace(bt);
     }
 
-    threads::detail::thread_pool_base* get_pool(
-        thread_id_type const& id, error_code& ec)
+    threads::detail::thread_pool_base* get_pool(thread_id_type const& id, error_code& ec)
     {
         if (PIKA_UNLIKELY(!id))
         {
-            PIKA_THROWS_IF(ec, pika::error::null_thread_id,
-                "pika::threads::detail::get_pool",
+            PIKA_THROWS_IF(ec, pika::error::null_thread_id, "pika::threads::detail::get_pool",
                 "null thread id encountered");
             return nullptr;
         }
@@ -354,10 +325,9 @@ namespace pika::this_thread {
     ///
     /// If the suspension was aborted, this function will throw a
     /// \a yield_aborted exception.
-    threads::detail::thread_restart_state suspend(
-        threads::detail::thread_schedule_state state,
-        threads::detail::thread_id_type nextid,
-        detail::thread_description const& description, error_code& ec)
+    threads::detail::thread_restart_state suspend(threads::detail::thread_schedule_state state,
+        threads::detail::thread_id_type nextid, detail::thread_description const& description,
+        error_code& ec)
     {
         // let the thread manager do other things while waiting
         threads::detail::thread_self& self = threads::detail::get_self();
@@ -379,8 +349,7 @@ namespace pika::this_thread {
             util::verify_no_locks();
 #endif
 #ifdef PIKA_HAVE_THREAD_DESCRIPTION
-            threads::detail::reset_lco_description desc(
-                id.noref(), description, ec);
+            threads::detail::reset_lco_description desc(id.noref(), description, ec);
 #else
             PIKA_UNUSED(description);
 #endif
@@ -393,17 +362,14 @@ namespace pika::this_thread {
                 get_thread_id_data(nextid)->get_scheduler_base() !=
                     get_thread_id_data(id)->get_scheduler_base())
             {
-                auto* scheduler =
-                    get_thread_id_data(nextid)->get_scheduler_base();
-                scheduler->schedule_thread(
-                    PIKA_MOVE(nextid), execution::thread_schedule_hint());
-                statex = self.yield(threads::detail::thread_result_type(
-                    state, threads::detail::invalid_thread_id));
+                auto* scheduler = get_thread_id_data(nextid)->get_scheduler_base();
+                scheduler->schedule_thread(PIKA_MOVE(nextid), execution::thread_schedule_hint());
+                statex = self.yield(
+                    threads::detail::thread_result_type(state, threads::detail::invalid_thread_id));
             }
             else
             {
-                statex = self.yield(threads::detail::thread_result_type(
-                    state, PIKA_MOVE(nextid)));
+                statex = self.yield(threads::detail::thread_result_type(state, PIKA_MOVE(nextid)));
             }
         }
 
@@ -416,8 +382,7 @@ namespace pika::this_thread {
         if (statex == threads::detail::thread_restart_state::abort)
         {
             PIKA_THROWS_IF(ec, pika::error::yield_aborted, "suspend",
-                "thread({}, {}) aborted (yield returned wait_abort)",
-                id.noref(),
+                "thread({}, {}) aborted (yield returned wait_abort)", id.noref(),
                 threads::detail::get_thread_description(id.noref()));
         }
 
@@ -427,10 +392,9 @@ namespace pika::this_thread {
         return statex;
     }
 
-    threads::detail::thread_restart_state suspend(
-        pika::chrono::steady_time_point const& abs_time,
-        threads::detail::thread_id_type nextid,
-        detail::thread_description const& description, error_code& ec)
+    threads::detail::thread_restart_state suspend(pika::chrono::steady_time_point const& abs_time,
+        threads::detail::thread_id_type nextid, detail::thread_description const& description,
+        error_code& ec)
     {
         // schedule a thread waking us up at_time
         threads::detail::thread_self& self = threads::detail::get_self();
@@ -453,8 +417,7 @@ namespace pika::this_thread {
             util::verify_no_locks();
 #endif
 #ifdef PIKA_HAVE_THREAD_DESCRIPTION
-            threads::detail::reset_lco_description desc(
-                id.noref(), description, ec);
+            threads::detail::reset_lco_description desc(id.noref(), description, ec);
 #else
             PIKA_UNUSED(description);
 #endif
@@ -463,8 +426,7 @@ namespace pika::this_thread {
 #endif
             std::atomic<bool> timer_started(false);
             threads::detail::thread_id_ref_type timer_id =
-                threads::detail::set_thread_state(id.noref(), abs_time,
-                    &timer_started,
+                threads::detail::set_thread_state(id.noref(), abs_time, &timer_started,
                     threads::detail::thread_schedule_state::pending,
                     threads::detail::thread_restart_state::timeout,
                     execution::thread_priority::boost, true, ec);
@@ -477,10 +439,8 @@ namespace pika::this_thread {
                 get_thread_id_data(nextid)->get_scheduler_base() !=
                     get_thread_id_data(id)->get_scheduler_base())
             {
-                auto* scheduler =
-                    get_thread_id_data(nextid)->get_scheduler_base();
-                scheduler->schedule_thread(
-                    PIKA_MOVE(nextid), execution::thread_schedule_hint());
+                auto* scheduler = get_thread_id_data(nextid)->get_scheduler_base();
+                scheduler->schedule_thread(PIKA_MOVE(nextid), execution::thread_schedule_hint());
                 statex = self.yield(threads::detail::thread_result_type(
                     threads::detail::thread_schedule_state::suspended,
                     threads::detail::invalid_thread_id));
@@ -488,23 +448,20 @@ namespace pika::this_thread {
             else
             {
                 statex = self.yield(threads::detail::thread_result_type(
-                    threads::detail::thread_schedule_state::suspended,
-                    PIKA_MOVE(nextid)));
+                    threads::detail::thread_schedule_state::suspended, PIKA_MOVE(nextid)));
             }
 
             if (statex != threads::detail::thread_restart_state::timeout)
             {
-                PIKA_ASSERT(
-                    statex == threads::detail::thread_restart_state::abort ||
+                PIKA_ASSERT(statex == threads::detail::thread_restart_state::abort ||
                     statex == threads::detail::thread_restart_state::signaled);
                 error_code ec1(throwmode::lightweight);    // do not throw
                 pika::util::yield_while(
-                    [&timer_started]() { return !timer_started.load(); },
-                    "set_thread_state_timed");
+                    [&timer_started]() { return !timer_started.load(); }, "set_thread_state_timed");
                 threads::detail::set_thread_state(timer_id.noref(),
                     threads::detail::thread_schedule_state::pending,
-                    threads::detail::thread_restart_state::abort,
-                    execution::thread_priority::boost, true, ec1);
+                    threads::detail::thread_restart_state::abort, execution::thread_priority::boost,
+                    true, ec1);
             }
         }
 
@@ -517,8 +474,7 @@ namespace pika::this_thread {
         if (statex == threads::detail::thread_restart_state::abort)
         {
             PIKA_THROWS_IF(ec, pika::error::yield_aborted, "suspend_at",
-                "thread({}, {}) aborted (yield returned wait_abort)",
-                id.noref(),
+                "thread({}, {}) aborted (yield returned wait_abort)", id.noref(),
                 threads::detail::get_thread_description(id.noref()));
         }
 
@@ -554,11 +510,10 @@ namespace pika::this_thread {
         std::ptrdiff_t remaining_stack = get_available_stack_space();
         if (remaining_stack < 0)
         {
-            PIKA_THROW_EXCEPTION(pika::error::out_of_memory,
-                "has_sufficient_stack_space", "Stack overflow");
+            PIKA_THROW_EXCEPTION(
+                pika::error::out_of_memory, "has_sufficient_stack_space", "Stack overflow");
         }
-        bool sufficient_stack_space =
-            std::size_t(remaining_stack) >= space_needed;
+        bool sufficient_stack_space = std::size_t(remaining_stack) >= space_needed;
 
         return sufficient_stack_space;
 #else
